@@ -1,7 +1,13 @@
+const bsStatus = require('../browserstack-send-status')
+
 module.exports = {
+  ...bsStatus(),
+
+  '@tags': ['history'],
+
   'named views': function (browser) {
     browser
-    .url('http://localhost:8080/named-views/')
+      .url('http://localhost:8080/named-views/')
       .waitForElementVisible('#app', 1000)
       .assert.count('li a', 2)
       // assert correct href with base
@@ -24,8 +30,8 @@ module.exports = {
       .assert.containsText('.view.two', 'bar')
       .assert.containsText('.view.three', 'baz')
 
-    // check initial visit
-    .url('http://localhost:8080/named-views/other')
+      // check initial visit
+      .url('http://localhost:8080/named-views/other')
       .waitForElementVisible('#app', 1000)
       .assert.containsText('.view.one', 'baz')
       .assert.containsText('.view.two', 'bar')
